import org.apache.log4j.Logger;
import com.ibm.mq.pcf.CMQCFC;
import com.ibm.mq.pcf.PCFMessage;
import com.ibm.mq.pcf.PCFParameter;
import java.io.IOException;
import java.lang.reflect.Field;
import java.util.Enumeration;
import java.util.*;
import com.ibm.mq.*; // Include the WebSphere MQ classes for Java package

/**
* A collection of utilities for handling MQ with XML.
* @author      Created by Sam Garforth
* Created on 04-Nov-2005.
* @version     $Name:  $ $Revision: 1.3 $ $Date: 2005/11/04 11:23:05 $
* @since       1.0.
**/
public class MQUtilities
{
  /** Interface/handle to the log4j error logger.   */
  private Logger logger;
  /** Map of MQ reason code names and values. */
  Map reasonCodes = new HashMap();
  /** Map of MQ command names and values. */
  Map commands = new HashMap();
  /** Map of MQ string names and values. */
  Map stringNames = new HashMap();
  /**
   * Constructor gets handle to the logger and sets up the maps of MQ constants.
   */
  public MQUtilities()
  {
    logger = Logger.getLogger(this.getClass());
    setupMaps();
  }

  /**
   * Converts a single PCF MQ messages to a piece of an XML string i.e. an XML string without the root header and tail.
   * This is a PCF message from the PCF support pac.
   * @param pcfMessage a PCFMessage created using the PCF support pac.
   * @return XML piece string representing the PCF message.
   * @throws MQException
   * @throws IOException
   */
  private String xmlPieceFromPCFMessage(PCFMessage pcfMessage)
    throws MQException, IOException
  {
    String stdout = "";
    Enumeration pcfEnum = pcfMessage.getParameters();
    stdout = stdout + "<MESSAGE>\n";
    stdout =
      stdout
        + "<COMMAND>"
        + getCommandName(pcfMessage.getCommand())
        + "</COMMAND>\n";
    stdout =
      stdout + "<REASON>" + getReasonName(pcfMessage.getReason()) + "</REASON>\n";
    while (pcfEnum.hasMoreElements())
    {
      PCFParameter elt = (PCFParameter)pcfEnum.nextElement();
      String parameterName = getStringName(elt.getParameter());
      stdout = stdout + "<" + parameterName + ">";
      if (elt.getType() == CMQCFC.MQCFT_STRING_LIST)
      {
        String strings[] = (String[])elt.getValue();
        for (int i = 0; i < strings.length; i++)
        {
          stdout = stdout + "<STRING>" + strings[i] + "</STRING>\n";
        }
      }
      else
        stdout = stdout + elt.getValue().toString();
      stdout = stdout + "</" + parameterName + ">\n";
    }
    stdout = stdout + "</MESSAGE>\n";
    return stdout;
  }
  
  /**
   * Converts an MQ integer to its string constant name.
   * @param stringInt the MQ integer.
   * @return the MQ constant name of the integer.
   */
  private String getStringName(int stringInt)
  {
    return (String)stringNames.get(new Integer(stringInt));
  }
  /**
   * Converts a constant integer to its MQ command name.
   * @param stringInt the MQ integer.
   * @return the MQ command name represented by the constant integer.
   */
  private String getCommandName(int stringInt)
  {
    return (String)commands.get(new Integer(stringInt));
  }
  /**
   * Sets up the maps for converting MQ constants to strings by querying the MQ class libraries. This means
   * that the code will work without change for future releases of MQ.
   */
  public void setupMaps()
  {
    setupReasonNameSub("com.ibm.mq.pcf.CMQC", "MQRC", reasonCodes);
    setupReasonNameSub("com.ibm.mq.pcf.CMQCFC", "MQRC", reasonCodes);
    setupReasonNameSub("com.ibm.mq.pcf.CMQCFC", "MQCMD", commands);
    setupReasonNameSub("com.ibm.mq.pcf.CMQC", "MQCA", stringNames);
    setupReasonNameSub("com.ibm.mq.pcf.CMQCFC", "MQCA", stringNames);
    setupReasonNameSub("com.ibm.mq.pcf.CMQC", "MQIA", stringNames);
  }
  /**
   * Sets up the maps for converting MQ constants to strings by querying the MQ class libraries. This is a subroutine called by setupMaps().
   * @param className the MQ class to be queried for the constants.
   * @param prefix the prefix of the constants names to identify the appropriate ones.
   * @param theMap the map to store the information in.
   */
  public void setupReasonNameSub(String className, String prefix, Map theMap)
  {
    Class c;
    logger.info("about to load class " + className);
    try
    {
      c = Class.forName(className);
    }
    catch (Exception ex)
    {
      logger.error("Class loading error" + ex.toString());
      return;
    }
    logger.info("loaded class");
    Field[] fields = c.getFields();
    for (int i = 0; i < fields.length; i++)
    {
      String name;
      if (fields[i].getType() == int.class)
      {
        name = fields[i].getName();
        if (name.startsWith(prefix))
        {
          try
          {
            Integer theInt = new Integer(fields[i].getInt(fields[i]));
            theMap.put(theInt, fields[i].getName());
          }
          catch (Exception ex)
          {
            logger.error("Class loading error" + ex.toString(), ex);
            return;
          }
        }
      }
    }
    logger.info("break");
  }
  /**
   * Converts an MQ reason code to a string explaining it.
   * @param stringInt the MQ reason code integer.
   * @return the string identifying the MQ reason code.
   */
  public String getReasonName(int stringInt)
  {
    return (String)reasonCodes.get(new Integer(stringInt));
  }
  
  /*
   * Converts an array list of PCF MQ messages to an XML string. These are PCF messages from the PCF support pac.
   * @param messageCollection an arraylist of MQ PCF messages.
   * @return XML string representing all the PCF messages in the collection.
   * @throws MQException
   * @throws IOException
   */
  protected String xmlFromPCFMessageCollection(ArrayList messageCollection)
    throws MQException, IOException
  {
    MQMessage retrievedMessage;
    String stdout = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
    stdout = stdout + "<EventMonitor version=\"0.1\" class=\"" + "MQUtilities" + "\">";
    Iterator mi = messageCollection.iterator();
    while (mi.hasNext())
    {
      retrievedMessage = (MQMessage)mi.next();
      PCFMessage pcfMessage = new PCFMessage(retrievedMessage);
      stdout = stdout + xmlPieceFromPCFMessage(pcfMessage);
    }
    stdout = stdout + "</EventMonitor>";
    return stdout;
  }
}
